from setuptools import setup, find_packages

setup(
    name='my_package2017',                    # Your package name
    version='0.1',                        # Version number
    packages=find_packages(),             # Automatically find packages
    install_requires=[],                  # List dependencies if any
    author='Jhansi Yadav',                   # Your name
    author_email='jhansiyadavaradhyula657@gmail.com',# Your email
    description='A brief description of your package',
    url='https://github.com/jhansiyadavaradhyula657/my_package2017', # Your project URL
)
